@@ -1,6 +1,9 @@
-from collections import deque
+from capris.core import run_command
 from capris.runnable import Runnable
-from capris.utils import option_string, which
+from capris.utils import option_iterable, which
+
+__all__ = ['Command']
+
 
 class Command(Runnable):
     def __init__(self, command, *positional, **options):
@@ -11,46 +14,44 @@ class Command(Runnable):
         self.env = {}
 
     @property
-    def absolute(self):
+    def absolute(self, path=None):
         copy = self.copy()
-        copy.command = which(self.command)
+        copy.command = which(self.command, path)
         return copy
 
     def __iter__(self):
-        if self.base_command is not None:
+        if self.base_command:
             for item in self.base_command:
                 yield item
 
         yield self.command
         if self.positional or self.options:
-            for item in option_string(self.positional, self.options):
+            for item in option_iterable(self.positional, self.options):
                 yield item
 
+    def run(self, **kwargs):
+        env = self.env.copy()
+        if 'env' in kwargs:
+            env.update(kwargs.pop('env'))
+        kwargs['env'] = env
+        response = run_command(tuple(self), **kwargs)
+        return response
 
     def __str__(self):
-        stack = [self.command]
-        if self.positional or self.options:
-            stack.extend(option_string(self.positional, self.options))
-
-        if self.base_command is not None:
-            newstack = [str(self.base_command)]
-            for item in stack:
-                newstack.append(item)
-            stack = newstack
-
-        return ' '.join(stack)
+        return ' '.join(self)
 
     def __getattr__(self, attribute):
         values = self.__dict__
-        if attribute not in values:
-            attribute = attribute.replace('_', '-')
-            return self.subcommand(attribute)
+        if attribute in values:
+            return values[attribute]
 
-        return values[attribute]
+        attribute = attribute.replace('_', '-')
+        return self.subcommand(attribute)
 
     def copy(self):
         copy = self.__class__(self.command, *self.positional, **self.options)
         copy.base_command = self.base_command
+        copy.env = self.env.copy()
         return copy
 
     def __call__(self, *args, **kwargs):
@@ -62,4 +63,5 @@ class Command(Runnable):
     def subcommand(self, command):
         subcommand = self.__class__(command)
         subcommand.base_command = self
+        subcommand.env = self.env.copy()
         return subcommand
