@@ -1,6 +1,9 @@
 from capris.core import run
 from capris.runnable import Runnable
 
+__all__ = ['IOStream']
+
+
 class IOStream(Runnable):
     def __init__(self, runnable):
         self.runnable = runnable
@@ -25,17 +28,21 @@ class IOStream(Runnable):
 
     def __iter__(self):
         iterable = list(self.runnable)
-        if isinstance(iterable[0], list):
+        if isinstance(iterable[0], tuple):
             for item in iterable:
                 yield item
             return
         yield iterable
 
+    def register(self, *callbacks):
+        for item in callbacks:
+            self.callbacks.append(item)
+
     def run(self, *args, **kwargs):
         if 'data' not in kwargs and self.input_file is not None:
             kwargs['data'] = self.input_file.read()
 
-        response = run(list(self), *args, **kwargs)
+        response = run(tuple(self), *args, **kwargs)
         if self.output_file is not None:
             data = response.std_out
             self.output_file.write(data)
