@@ -1,6 +1,9 @@
-from capris.core import run_command
+from capris.core import run
 from capris.runnable import Runnable
 
+__all__ = ['Pipe']
+
+
 class Pipe(Runnable):
     def __init__(self, *commands):
         self.commands = list(commands)
@@ -11,9 +14,12 @@ class Pipe(Runnable):
             stack.append(str(item))
         return ' | '.join(stack)
 
+    def run(self, *args, **kwargs):
+        return run(tuple(self), *args, **kwargs)
+
     def __iter__(self):
         for item in self.commands:
-            yield list(item)
+            yield tuple(item)
 
     def append(self, command):
         self.commands.append(command)
