@@ -23,17 +23,18 @@ class Helpers(object):
 
 class CaprisTest(unittest.TestCase):
     helpers = Helpers()
+
     def setUp(self):
         self.grep = Command('grep')
-        self.cat  = Command('cat')
-        self.ls   = Command('ls')
+        self.cat = Command('cat')
+        self.ls = Command('ls')
 
 
 def get_tests():
     import capris.tests
-    modules = [m[:-3] for m in os.listdir(capris.tests.__path__[0]) \
-               if not m.startswith('__') and \
-                      m.endswith('.py')]
+    modules = [m[:-3] for m in os.listdir(capris.tests.__path__[0])
+               if not m.startswith('__')
+               and m.endswith('.py')]
     loader = unittest.TestLoader()
 
     for item in modules:
