@@ -1,10 +1,14 @@
-from capris.command import Command
-from capris.pipe import Pipe
-from capris.iostream import IOStream
 from capris.runnable import Runnable
+from capris.command import Command
+from capris.iostream import IOStream
+from capris.pipe import Pipe
+
+__all__ = ['TransactionPipe', 'TransactionIOStream', 'TransactionCommand']
 
 
 class TransactionRunnable(Runnable):
+    history = None
+
     def __or__(self, other):
         if isinstance(other, Pipe):
             other.append(self)
@@ -30,8 +34,13 @@ class TransactionRunnable(Runnable):
             ))
 
 
-class TransactionPipe(TransactionRunnable, Pipe): pass
-class TransactionIOStream(TransactionRunnable, IOStream): pass
+class TransactionPipe(TransactionRunnable, Pipe):
+    pass
+
+
+class TransactionIOStream(TransactionRunnable, IOStream):
+    pass
+
 
 class TransactionCommand(TransactionRunnable, Command):
     def copy(self):
